fluent
Safe HaskellNone
LanguageHaskell2010

Language.Fluent.Number

Synopsis

Documentation

data Style Source #

What a number denotes, which determines how it is formatted.

Constructors

Decimal

A plain number: 12.5

Percent

A ratio, shown as a percentage: 1,250%

Currency Text

An amount of the currency with the given ISO 4217 code: Currency EUR gives €12.50

Unit Text

A measurement in the given CLDR unit: Unit "second" gives 12.5 s

Instances

Instances details
Show Style Source # 
Instance details

Defined in Language.Fluent.Number

Methods

showsPrec :: Int -> Style -> ShowS #

show :: Style -> String #

showList :: [Style] -> ShowS #

Eq Style Source # 
Instance details

Defined in Language.Fluent.Number

Methods

(==) :: Style -> Style -> Bool #

(/=) :: Style -> Style -> Bool #